Index: src/lib/file-copy.c
===================================================================
RCS file: /home/cvs/dovecot/src/lib/file-copy.c,v
retrieving revision 1.1.2.3
diff -u -r1.1.2.3 file-copy.c
--- src/lib/file-copy.c	1 Jul 2006 17:45:16 -0000	1.1.2.3
+++ src/lib/file-copy.c	9 Aug 2006 22:54:17 -0000
@@ -20,6 +20,10 @@
 	int fd_in, fd_out;
 	off_t ret;
 
+#ifdef AVOID_HARDLINKS
+	try_hardlink = FALSE;
+#endif
+
 	if (try_hardlink) {
 		/* see if hardlinking works */
 		if (link(srcpath, tmppath) == 0)
Index: src/lib/file-dotlock.c
===================================================================
RCS file: /home/cvs/dovecot/src/lib/file-dotlock.c,v
retrieving revision 1.35.2.3
diff -u -r1.35.2.3 file-dotlock.c
--- src/lib/file-dotlock.c	8 Jun 2006 16:13:46 -0000	1.35.2.3
+++ src/lib/file-dotlock.c	9 Aug 2006 22:54:17 -0000
@@ -401,9 +401,13 @@
 			if ((flags & DOTLOCK_CREATE_FLAG_CHECKONLY) != 0)
 				break;
 
-			ret = set->use_excl_lock ?
-				try_create_lock_excl(&lock_info, write_pid) :
-				try_create_lock_hardlink(&lock_info, write_pid,
+			ret = 
+#ifdef AVOID_HARDLINKS
+				TRUE || 
+#endif
+				set->use_excl_lock ?
+					try_create_lock_excl(&lock_info, write_pid) :
+					try_create_lock_hardlink(&lock_info, write_pid,
 							 tmp_path);
 			if (ret != 0)
 				break;
Index: src/lib-storage/index/maildir/maildir-save.c
===================================================================
RCS file: /home/cvs/dovecot/src/lib-storage/index/maildir/maildir-save.c,v
retrieving revision 1.70.2.2
diff -u -r1.70.2.2 maildir-save.c
--- src/lib-storage/index/maildir/maildir-save.c	1 Jul 2006 18:33:03 -0000	1.70.2.2
+++ src/lib-storage/index/maildir/maildir-save.c	9 Aug 2006 22:54:18 -0000
@@ -72,6 +72,20 @@
 		t_strconcat(ctx->newdir, "/", destname, NULL) :
 		t_strconcat(ctx->curdir, "/", destname, NULL);
 
+#ifdef AVOID_HARDLINKS
+	if (rename(tmp_path, new_path) == 0)
+		ret = 0;
+	else {
+		ret = -1;
+		if (ENOSPACE(errno)) {
+			mail_storage_set_error(STORAGE(ctx->mbox->storage),
+					       "Not enough disk space");
+		} else {
+			mail_storage_set_critical(STORAGE(ctx->mbox->storage),
+				"rename(%s, %s) failed: %m", tmp_path, new_path);
+		}
+	}
+#else
 	if (link(tmp_path, new_path) == 0)
 		ret = 0;
 	else {
@@ -89,6 +103,8 @@
 		mail_storage_set_critical(STORAGE(ctx->mbox->storage),
 			"unlink(%s) failed: %m", tmp_path);
 	}
+#endif
+
 	t_pop();
 	return ret;
 }
